@@ -25,6 +25,8 @@ from threading import local
 from amqplib import client_0_8 as amqp
 from bson import dumps
 
+from utils import is_amqplib_connection_error
+
 __all__ = [
     'Publisher',
     ]
@@ -61,9 +63,12 @@ class Publisher:
         if getattr(self.channels, 'channel', None) is None:
             try:
                 self.channels.channel = self.connection_factory().channel()
-            except socket.error:
-                # Could not connect
-                return None
+            except (socket.error, IOError), e:
+                if is_amqplib_connection_error(e):
+                    # Could not connect
+                    return None
+                # Unknown error mode : don't hide it.
+                raise
         return self.channels.channel
 
     def __call__(self, report):
@@ -86,7 +91,11 @@ class Publisher:
         try:
             channel.basic_publish(
                 message, self.exchange_name, routing_key=self.routing_key)
-        except socket.error:
+        except (socket.error, IOError), e:
             self.channels.channel = None
-            return None
+            if is_amqplib_connection_error(e):
+                # Could not connect / interrupted connection
+                return None
+            # Unknown error mode : don't hide it.
+            raise
         return report['id']
