@@ -23,7 +23,10 @@ import time
 
 import bson
 
-from utils import close_ignoring_EPIPE
+from utils import (
+    close_ignoring_EPIPE,
+    is_amqplib_connection_error,
+    )
 
 __all__ = [
     'Receiver',
@@ -81,7 +84,10 @@ class Receiver:
                (not self.went_bad or time.time() < self.went_bad + 120)):
             try:
                 self._run_forever()
-            except socket.error:
+            except (socket.error, IOError), e:
+                if not is_amqplib_connection_error(e):
+                    # Something unknown went wrong.
+                    raise
                 if not self.went_bad:
                     self.went_bad = time.time()
                 # Don't probe immediately, give the network/process time to
