@@ -21,6 +21,8 @@ import socket
 
 __all__ = [
     'close_ignoring_EPIPE',
+    'is_amqplib_ioerror',
+    'is_amqplib_connection_error',
     ]
 
 
@@ -30,3 +32,14 @@ def close_ignoring_EPIPE(closable):
     except socket.error, e:
         if e.errno != errno.EPIPE:
             raise
+
+
+def is_amqplib_ioerror(e):
+    """Returns True if e is an amqplib internal exception."""
+    # Raised by amqplib rather than socket.error on ssl issues and short reads.
+    return type(e) is IOError and e.args == ('Socket error',)
+
+
+def is_amqplib_connection_error(e):
+    """Return True if e was (probably) raised due to a connection issue."""
+    return isinstance(e, socket.error) or is_amqplib_ioerror(e)
